.:TSETMC:. :: شناسه نماد

PSB is being developed by Pooya Paridel.
شركت مديريت فناوري بورس تهران
Tehran Securities Exchange Technology Management Co
شناسه

کد 12 رقمی نماد | IRO7SDIP0001
کد 5 رقمی نماد | SDIP1
نام لاتین شرکت | Sadid Group
کد 4 رقمی شرکت | SDIP
نام شرکت | گروه‌صنعتي‌سديد
نماد فارسی | وسديد - لغو پذیرش شده
نماد 30 رقمی فارسی | گروه ‌صنعتي‌سديد
کد 12 رقمی شرکت | IRO7SDIP0002
بازار | بازار پايه نارنجي فرابورس
کد تابلو | 7
کد گروه صنعت | 27
گروه صنعت | فلزات اساسي
کد زیر گروه صنعت | 2799
زیر گروه صنعت | استخراج ساير فلزات اساسي